/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Joe Hewitt <hewitt@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* ==== prefpanels.css ==================================================
   == Styles used by all preference panels in the Communicator suite.
   ====================================================================== */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
/* ::::: Themes ::::: */

#skinsTree {
  height: 80px;
}

*|*.themesLink {
  -moz-margin-start: 5px;
  text-decoration: underline;
  color: blue;
  cursor: pointer;
}

*|*.themesLink:active {
  color: red;
}

#previewImageContainer {
  height: 93px; 
  padding: 1px;
}

#previewImage {
  max-width: 355px; 
  min-width: 355px;
  max-height: 85px;
  min-height: 85px;
}

/* ::::: Fonts ::::: */

#sizeVar,
#sizeMono {
  width: 4em;
}

.prefpanel-font-list {
  -moz-box-flex: 1;
}

/* ::::: Mouse Wheel ::::: */

#mouseWheelMode {
  width: 9em;
}
